.. image:: ../../_static/CSAwesomeLogo.png
    :width: 350
    :align: center

ArrayList
::::::::::::::::::::

Class Periods: 10-12

AP CSA Exam Weighting: 2.5–7.5%

.. toctree::
   :maxdepth: 3

   topic-7-1-arraylist-basics.rst
   topic-7-2-arraylist-methods.rst
   topic-7-3-arraylist-loops.rst
   topic-7-4-arraylist-algorithms.rst
   topic-7-5-searching.rst
   topic-7-6-sorting.rst
   topic-7-7-data-ethics.rst
   topic-7-8-summary.rst
   topic-input-files.rst
   ListParsonsPractice.rst
   topic-7-9-toggle-problems.rst
   listPractice.rst
   Exercises.rst
   CBLabs.rst


